import {Component, OnInit} from '@angular/core'
import {FormBuilder, FormControl, FormGroup, Validators} from '@angular/forms'
import {AccountService} from '../../services/account.service'
import {Router} from '@angular/router'
import {ErrorHandler, ErrorModel, ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.sass']
})
export class LoginComponent extends ErrorHandler implements OnInit {
  readonly handledErrorModels: ErrorModel[] = [{
    filter: error => error.status === 401,
    messageProducer: () => 'Les identifiants entrés sont invalides.'
  }]

  form: FormGroup
  idFormControl: FormControl
  passwordFormControl: FormControl

  invalidCredentials = false

  constructor(
    private formBuilder: FormBuilder,
    private accountService: AccountService,
    private router: Router,
    errorService: ErrorService
  ) {
    super(errorService)
  }

  ngOnInit(): void {
    if (this.accountService.isLoggedIn()) {
      this.router.navigate(['/color'])
    }

    this.idFormControl = this.formBuilder.control(null, Validators.compose([Validators.required, Validators.pattern(new RegExp('^[0-9]+$'))]))
    this.passwordFormControl = this.formBuilder.control(null, Validators.required)
    this.form = this.formBuilder.group({
      id: this.idFormControl,
      password: this.passwordFormControl
    })
  }

  submit() {
    this.accountService.login(
      this.idFormControl.value,
      this.passwordFormControl.value,
      () => this.router.navigate(['/color'])
    )
  }
}
